==> Crypt-Trifid-0.04.tar.gz: Crypt-Trifid-0.04/lib/Crypt/Trifid/Utils.pm <==
package Crypt::Trifid::Utils;

$Crypt::Trifid::Utils::VERSION   = '0.04';
$Crypt::Trifid::Utils::AUTHORITY = 'cpan:MANWAR';

=head1 NAME

Crypt::Trifid::Utils - Helper package for Crypt::Trifid.

=head1 VERSION

Version 0.04

=cut

use 5.006;
use strict; use warnings;

use Data::Dumper;
use vars qw(@ISA @EXPORT_OK);

require Exporter;
@ISA       = qw(Exporter);
@EXPORT_OK = qw(generate_chart);

=head1 DESCRIPTION

B<FOR INTERNAL USE ONLY>

=cut

sub generate_chart {

    my $chars = generate_charset();
    my $chart = {};
    foreach my $i (0..2) {
        foreach my $j (0..2) {
            foreach my $k (0..2) {
                $chart->{$chars->[$i]->[$j]->[$k]} = sprintf("%d%d%d", $i+1, $j+1, $k+1);
            }
        }
    }

    return $chart;
}

#
#
# PRIVATE METHODS

sub generate_charset {

    my @chars = ('A' .. 'Z', ' ');
    my $chars = [];
    my $seen  = {};
    foreach my $i (0..2) {
        foreach my $j (0..2) {
            foreach my $k (0..2) {
                my $char = '';
                while ($char eq '') {
                    $char = _get_char(@chars);
                    if (exists $seen->{$char}) {
                        $char = '';
                    }
                    else {
                        $seen->{$char} = 1;
                    }
                }
                $chars->[$i]->[$j]->[$k] = $char;
            }
        }
    }

    return $chars;
}

sub _get_char { my (@chars) = @_; return $chars[ rand @chars ]; }

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/Manwar/Crypt-Trifid>

=head1 BUGS

Please report any bugs/feature requests to C<bug-crypt-trifid at rt.cpan.org>  or
through the web interface at  L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Crypt-Trifid>.
I will be notified & then you'll automatically be notified of progress on your bug
as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Crypt::Trifid::Utils

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Crypt-Trifid>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Crypt-Trifid>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Crypt-Trifid>

=item * Search CPAN

L<http://search.cpan.org/dist/Crypt-Trifid/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2014 - 2015 Mohammad S Anwar.

This program  is  free software; you can redistribute it and / or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a copy  of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Crypt::Trifid::Utils

==> Crypt-Trifid-0.05.tar.gz: Crypt-Trifid-0.05/lib/Crypt/Trifid/Utils.pm <==
package Crypt::Trifid::Utils;

$Crypt::Trifid::Utils::VERSION   = '0.05';
$Crypt::Trifid::Utils::AUTHORITY = 'cpan:MANWAR';

=head1 NAME

Crypt::Trifid::Utils - Helper package for Crypt::Trifid.

=head1 VERSION

Version 0.05

=cut

use 5.006;
use strict; use warnings;

use Data::Dumper;
use vars qw(@ISA @EXPORT_OK);

require Exporter;
@ISA       = qw(Exporter);
@EXPORT_OK = qw(generate_chart);

=head1 DESCRIPTION

B<FOR INTERNAL USE ONLY>

=cut

sub generate_chart {

    my $chars = _generate_charset();
    my $chart = {};
    foreach my $i (0..2) {
        foreach my $j (0..2) {
            foreach my $k (0..2) {
                $chart->{$chars->[$i]->[$j]->[$k]} = sprintf("%d%d%d", $i+1, $j+1, $k+1);
            }
        }
    }

    return $chart;
}

#
#
# PRIVATE METHODS

sub _generate_charset {

    my @chars = ('A' .. 'Z', ' ');
    my $chars = [];
    my $seen  = {};
    foreach my $i (0..2) {
        foreach my $j (0..2) {
            foreach my $k (0..2) {
                my $char = '';
                while ($char eq '') {
                    $char = _get_char(@chars);
                    if (exists $seen->{$char}) {
                        $char = '';
                    }
                    else {
                        $seen->{$char} = 1;
                    }
                }
                $chars->[$i]->[$j]->[$k] = $char;
            }
        }
    }

    return $chars;
}

sub _get_char { my (@chars) = @_; return $chars[ rand @chars ]; }

=head1 AUTHOR

Mohammad S Anwar, C<< <mohammad.anwar at yahoo.com> >>

=head1 REPOSITORY

L<https://github.com/Manwar/Crypt-Trifid>

=head1 BUGS

Please report any bugs/feature requests to C<bug-crypt-trifid at rt.cpan.org>  or
through the web interface at  L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=Crypt-Trifid>.
I will be notified & then you'll automatically be notified of progress on your bug
as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc Crypt::Trifid::Utils

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=Crypt-Trifid>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/Crypt-Trifid>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/Crypt-Trifid>

=item * Search CPAN

L<http://search.cpan.org/dist/Crypt-Trifid/>

=back

=head1 LICENSE AND COPYRIGHT

Copyright (C) 2014 - 2015 Mohammad S Anwar.

This program  is  free software; you can redistribute it and / or modify it under
the  terms  of the the Artistic License (2.0). You may obtain a copy  of the full
license at:

L<http://www.perlfoundation.org/artistic_license_2_0>

Any  use,  modification, and distribution of the Standard or Modified Versions is
governed by this Artistic License.By using, modifying or distributing the Package,
you accept this license. Do not use, modify, or distribute the Package, if you do
not accept this license.

If your Modified Version has been derived from a Modified Version made by someone
other than you,you are nevertheless required to ensure that your Modified Version
 complies with the requirements of this license.

This  license  does  not grant you the right to use any trademark,  service mark,
tradename, or logo of the Copyright Holder.

This license includes the non-exclusive, worldwide, free-of-charge patent license
to make,  have made, use,  offer to sell, sell, import and otherwise transfer the
Package with respect to any patent claims licensable by the Copyright Holder that
are  necessarily  infringed  by  the  Package. If you institute patent litigation
(including  a  cross-claim  or  counterclaim) against any party alleging that the
Package constitutes direct or contributory patent infringement,then this Artistic
License to you shall terminate on the date that such litigation is filed.

Disclaimer  of  Warranty:  THE  PACKAGE  IS  PROVIDED BY THE COPYRIGHT HOLDER AND
CONTRIBUTORS  "AS IS'  AND WITHOUT ANY EXPRESS OR IMPLIED WARRANTIES. THE IMPLIED
WARRANTIES    OF   MERCHANTABILITY,   FITNESS   FOR   A   PARTICULAR  PURPOSE, OR
NON-INFRINGEMENT ARE DISCLAIMED TO THE EXTENT PERMITTED BY YOUR LOCAL LAW. UNLESS
REQUIRED BY LAW, NO COPYRIGHT HOLDER OR CONTRIBUTOR WILL BE LIABLE FOR ANY DIRECT,
INDIRECT, INCIDENTAL,  OR CONSEQUENTIAL DAMAGES ARISING IN ANY WAY OUT OF THE USE
OF THE PACKAGE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

=cut

1; # End of Crypt::Trifid::Utils
